# Basich dataset operation libs

This code aims to execute the basic datasets operations (e.g., read and anonymize the records) in my Ph.D. research.

## Setup

- enable virtual env
    ```python -m venv .venv```

- update pip
    > python -m pip install --upgrade pip

- install requirements
  ```pip install -r requirements.txt```

